Uses of Annotation Interface
dev.despical.commandframework.annotations.Command
Packages that use Command
Package
Description
The main package of the Command Framework containing all
core classes and components related to the framework.
Provides an internal class responsible for handling command and subcommand confirmations.
Provides an internal class responsible for handling command cooldowns.
Provides internal utility classes and helpers for the Command Framework.
-
Uses of Command in dev.despical.commandframework
Methods in dev.despical.commandframework that return CommandModifier and TypeMethodDescriptionCommandArguments.getCommand()Retrieves the base command associated with this object.Methods in dev.despical.commandframework that return types with arguments of type CommandModifier and TypeMethodDescriptionCommandFramework.getAllCommands()Get a copy of registered commands and sub-commands.CommandRegistry.CommandMatcher.getAssociatedCommand(@NotNull String commandName, @NotNull String[] possibleArgs) CommandFramework.getCommands()Get a copy of registered commands.CommandRegistry.getCommands()CommandFramework.getSubCommands()Get a copy of registered sub-commands-.CommandRegistry.getSubCommands()Methods in dev.despical.commandframework with parameters of type CommandModifier and TypeMethodDescriptionprotected voidCommandRegistry.registerCommand(Command command, Method method, Object instance) This method registers a command along with its associated method and instance.Method parameters in dev.despical.commandframework with type arguments of type CommandModifier and TypeMethodDescriptionvoidMessage.setMessage(BiFunction<Command, CommandArguments, Boolean> message) Set a custom error message. -
Uses of Command in dev.despical.commandframework.confirmations
Methods in dev.despical.commandframework.confirmations with parameters of type CommandModifier and TypeMethodDescriptionbooleanConfirmationManager.checkConfirmations(org.bukkit.command.CommandSender sender, Command command, Method method) -
Uses of Command in dev.despical.commandframework.cooldown
Methods in dev.despical.commandframework.cooldown with parameters of type CommandModifier and TypeMethodDescriptionbooleanCooldownManager.hasCooldown(CommandArguments arguments, Command command, Method method) -
Uses of Command in dev.despical.commandframework.utils
Methods in dev.despical.commandframework.utils that return CommandModifier and TypeMethodDescriptionstatic CommandUtils.createCommand(Command command, String commandName) Methods in dev.despical.commandframework.utils with parameters of type CommandModifier and TypeMethodDescriptionstatic CommandUtils.createCommand(Command command, String commandName)