Uses of Class
dev.despical.commandframework.CommandArguments
Packages that use CommandArguments
Package
Description
The main package of the Command Framework containing all
core classes and components related to the framework.
Provides an internal class responsible for handling command cooldowns.
-
Uses of CommandArguments in dev.despical.commandframework
Methods in dev.despical.commandframework with parameters of type CommandArgumentsModifier and TypeMethodDescription@NotNull Object[]ParameterHandler.getParameterArray(Method method, CommandArguments commandArguments) Method parameters in dev.despical.commandframework with type arguments of type CommandArgumentsModifier and TypeMethodDescriptionfinal <T> voidCommandFramework.addCustomParameter(@NotNull Class<T> clazz, @NotNull Function<CommandArguments, T> function) Adds a custom parameter to the parameter handler using a class type.final <A,B extends A>
voidCommandFramework.addCustomParameter(@NotNull String value, @NotNull Function<CommandArguments, B> function) Adds a custom parameter to the parameter handler.<T> voidParameterHandler.addCustomParameter(@NotNull Class<T> clazz, @NotNull Function<CommandArguments, T> function) <A,B extends A>
voidParameterHandler.addCustomParameter(@NotNull String key, @NotNull Function<CommandArguments, B> function) voidMessage.setMessage(BiFunction<Command, CommandArguments, Boolean> message) Set a custom error message.Constructors in dev.despical.commandframework with parameters of type CommandArguments -
Uses of CommandArguments in dev.despical.commandframework.cooldown
Methods in dev.despical.commandframework.cooldown with parameters of type CommandArgumentsModifier and TypeMethodDescriptionbooleanCooldownManager.hasCooldown(CommandArguments arguments) booleanCooldownManager.hasCooldown(CommandArguments arguments, Command command, Method method)