Uses of Class
dev.despical.commandframework.CommandFramework
Packages that use CommandFramework
Package
Description
The main package of the Command Framework containing all
core classes and components related to the framework.
Provides an internal class responsible for handling command cooldowns.
-
Uses of CommandFramework in dev.despical.commandframework
Fields in dev.despical.commandframework declared as CommandFrameworkMethods in dev.despical.commandframework that return CommandFramework -
Uses of CommandFramework in dev.despical.commandframework.cooldown
Constructors in dev.despical.commandframework.cooldown with parameters of type CommandFramework